@@ -7,15 +7,15 @@
 
 START_TEST(test_create) {
   girara_session_t* session = girara_session_create();
-  fail_unless(session != NULL, "Could not create session");
+  ck_assert_msg(session != NULL, "Could not create session");
   girara_session_destroy(session);
 } END_TEST
 
 START_TEST(test_init) {
   girara_session_t* session = girara_session_create();
-  fail_unless(session != NULL, "Could not create session");
+  ck_assert_msg(session != NULL, "Could not create session");
   bool result = girara_session_init(session, NULL);
-  fail_unless(result == true, "Could not init session");
+  ck_assert_msg(result == true, "Could not init session");
   girara_session_destroy(session);
 } END_TEST
 
